pub struct Database { /* private fields */ }Expand description
A database wrapper
Contains (potentially) separate connections for readonly database instances and read/write instances.
This allows you to benefit from multi node database clusters which provide a read-only endpoint.
By if not readonly endpoint is configured the read-write endpoint is used instead.
Implementations